# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project uses date-based versioning.

<!-- scriv-insert-here -->

<a id='changelog-2023.12.19.1'></a>
## [2023.12.19.1] - 2023-12-19

### Changed

- Updated changelog management and versioning scheme.

- Updated requirements and lockfiles to support Django 4.
- Removed support for Django 2.2.

<a id='changelog-2023.12.19'></a>
## [2023.12.19] - 2023-12-19

### Changed

- Updated changelog management and versioning scheme.

- Updated requirements and lockfiles to support Django 4.
- Removed support for Django 2.2.

## [1.3.0] - 2023-01-17

## [1.2.1] - 2022-10-31

## [1.2.0] - 2022-06-24

## [1.1.0] - 2022-05-12

### Changed
- Bump `mitol-django-common` to `2.2.0`.

## [1.0.1] - 2021-11-16

## [1.0.0] - 2021-11-04

### Added
- Support for Python 3.9

### Changed

- Allowed for a wider range of dependency versions

### Removed
- Support for Python 3.6

## [0.1.0] - 2021-01-21

### Added

- Added initial implementation of `mitol-django-oauth-toolkit-extensions` library

[Unreleased]: https://github.com/mitodl/ol-django/compare/mitol-django-oauth-toolkit-extensions/v1.3.0...HEAD
[1.3.0]: https://github.com/mitodl/ol-django/compare/mitol-django-oauth-toolkit-extensions/v1.2.1...mitol-django-oauth-toolkit-extensions/v1.3.0
[1.2.1]: https://github.com/mitodl/ol-django/compare/mitol-django-oauth-toolkit-extensions/v1.2.0...mitol-django-oauth-toolkit-extensions/v1.2.1
[1.2.0]: https://github.com/mitodl/ol-django/compare/mitol-django-oauth-toolkit-extensions/v1.1.0...mitol-django-oauth-toolkit-extensions/v1.2.0
[1.1.0]: https://github.com/mitodl/ol-django/compare/mitol-django-oauth-toolkit-extensions/v1.0.1...mitol-django-oauth-toolkit-extensions/v1.1.0
[1.0.1]: https://github.com/mitodl/ol-django/compare/mitol-django-oauth-toolkit-extensions/v1.0.0...mitol-django-oauth-toolkit-extensions/v1.0.1
[1.0.0]: https://github.com/mitodl/ol-django/compare/mitol-django-oauth-toolkit-extensions/v0.1.0...mitol-django-oauth-toolkit-extensions/v1.0.0
[0.1.0]: https://github.com/mitodl/ol-django/compare/ffca0142e4bfea14881047d3af168bd4aa32f6fa...mitol-django-oauth-toolkit-extensions/v0.1.0
